summaryrefslogtreecommitdiffstats
path: root/src/kvilib/core/kvi_pointerlist.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kvilib/core/kvi_pointerlist.h')
-rw-r--r--src/kvilib/core/kvi_pointerlist.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/kvilib/core/kvi_pointerlist.h b/src/kvilib/core/kvi_pointerlist.h
index 2051036..5097000 100644
--- a/src/kvilib/core/kvi_pointerlist.h
+++ b/src/kvilib/core/kvi_pointerlist.h
@@ -288,7 +288,7 @@ public:
/// Iterating over pointers is also very fast and this
/// class contains an internal iterator that allows to
/// write loops in a compact and clean way.
/// See the first(), next(), current() and tqfindRef()
/// functions for the description of this feature.
///
/// There is also a non-const external iterator
@@ -618,7 +618,7 @@ public:
///
/// Returns the current iteration item
/// A call to this function MUST be preceded by a call to
- /// first(),last(),at() or tqfindRef()
+ /// first(),last(),at() or findRef()
///
T * current()
{
@@ -628,7 +628,7 @@ public:
///
/// Returns the current iteration item
/// A call to this function should be preceded by a call to
- /// first(),last(),at() or tqfindRef().
+ /// first(),last(),at() or findRef().
/// This function will return a NULL pointer if the current
/// item has been invalidated due to a remove operation.
///
@@ -641,7 +641,7 @@ public:
///
/// Returns an iterator pointing to the current item in the list.
/// A call to this function MUST be preceded by a call to
- /// first(),last(),at() or tqfindRef()
+ /// first(),last(),at() or findRef()
///
KviPointerListIterator<T> iteratorAtCurrent()
{
@@ -652,7 +652,7 @@ public:
/// Sets the iteration pointer to the next item in the list
/// and returns that item (or 0 if the end of the list has been reached)
/// A call to this function MUST be preceded by a _succesfull_ call to
- /// first(),last(),at() or tqfindRef().
+ /// first(),last(),at() or findRef().
///
T * next()
{
@@ -666,7 +666,7 @@ public:
/// Sets the iteration pointer to the previous item in the list
/// and returns that item (or 0 if the beginning of the list has been reached)
/// A call to this function MUST be preceded by a _succesfull_ call to
- /// first(),last(),at() or tqfindRef()
+ /// first(),last(),at() or findRef()
///
T * prev()
{
@@ -715,7 +715,7 @@ public:
/// and returns its position (zero based index) in the list or -1 if the
/// item cannot be found
///
- int tqfindRef(const T * d)
+ int findRef(const T * d)
{
int ret = 0;
for(T * t = first();t;t = next())
@@ -945,7 +945,7 @@ public:
///
bool removeRef(const T * d)
{
- if(tqfindRef(d) == -1)return false;
+ if(findRef(d) == -1)return false;
removeCurrentSafe();
return true;
}
@@ -957,7 +957,7 @@ public:
///
void insertAfter(const T * ref,const T * d)
{
- if(tqfindRef(ref) == -1)
+ if(findRef(ref) == -1)
{
append(d);
return;
@@ -981,7 +981,7 @@ public:
///
void insertBefore(const T * ref,const T * d)
{
- if(tqfindRef(ref) == -1)
+ if(findRef(ref) == -1)
{
prepend(d);
return;
@@ -288,7 +288,7 @@ public:
/// class contains an internal iterator that allows to
/// write loops in a compact and clean way.
-/// See the first(), next(), current() and tqfindRef()
+/// See the first(), next(), current() and findRef()
/// functions for the description of this feature.
///